# spec file for CERN program library 2004 for Scientific Linux
#
Summary: CERN program library 2004 for Scientific Linux
Name: cernlib
Version: 2004
Release: 1
Copyright: open source license
Group: Applications/high energy physics

Source0: lapack.tgz
Source1: include.tar.gz
Source2: src_cfortran.tar.gz
Source3: src_config.tar.gz
Source4: src_geant321.tar.gz
Source5: src_graflib.tar.gz
Source6: src_include.tar.gz
Source7: src_mathlib.tar.gz 
Source8: src_mclibs.tar.gz
Source9: src_packlib.tar.gz 
Source10: src_patchy.tar.gz
Source11: src_pawlib.tar.gz
Source12: src_phtools.tar.gz
Source13: src_scripts.tar.gz
Source14: Imakefile
Source15: plitar
Source16: patchy.tar.gz
Source17: src_xsneut95.tar.gz
Source18: Lapack_make_inc
Source19: Lapack_Makefile

URL: http://cernlib.web.cern.ch/cernlib/
Distribution: Lynx BCC Company
Vendor: European Organization for Nuclear Research (CERN)
Packager: Lynx BCC Company <http://www.lynx.ru>
BuildRoot: /tmp/cern-2004
Prefix: /usr/cernlib

%description
CERN program library is a large collection of general purpose libraries
and modules maintained and offered in both source and object code form
on the CERN. Most of these programs were developed at CERN and are
therefore oriented towards the needs of a physics research laboratory that
is general mathematics, data analysis, detectors simulation, 
data-handling etc... applicable to a wide range of problems.
 
#

%prep
%setup -c 

%build
CERN="$RPM_BUILD_ROOT/usr/cernlib"; export CERN;
PLITMP="/usr/src/redhat/SOURCES"; export PLITMP;
mkdir -p $CERN


# Unpack the source files and set up the build structure
#  e.g. /tmp/cernlib/2004/src (and lib)

cd $CERN
list=`ls $PLITMP/src_*.gz`
for ffile in $list
do
  gunzip -c $ffile | tar xf -
done

gunzip -c $PLITMP/include.tar.gz | tar xf -
gunzip -c $PLITMP/patchy.tar.gz | tar xf -

CERN_LEVEL=2004
export CERN_LEVEL
export CERN_ROOT=$CERN/$CERN_LEVEL
export CVSCOSRC=$CERN_ROOT/src
mkdir -p $CERN_ROOT/bin
export PATH=$CERN_ROOT/bin:$PATH
cp /usr/src/redhat/SOURCES/Imakefile $CERN_ROOT/src
cp $CERN/patchy/4.15/bin/ypatchy $CERN_ROOT/bin
cp $CERN/$CERN_LEVEL/src/scripts/cernlib $CERN_ROOT/bin

#

# Create the build directory structure
cd $CERN_ROOT
mkdir -p build bin lib build/log


#  Create Lapack
cd /usr/src/redhat/BUILD/cernlib-$CERN_LEVEL/LAPACK
cp /usr/src/redhat/SOURCES/Lapack_make_inc ./make.inc
cp /usr/src/redhat/SOURCES/Lapack_Makefile ./Makefile
gmake lib
cp -p lapack_Linux2418.a $CERN_ROOT/lib/liblapack3.a
cp -p blas_Linux2418.a $CERN_ROOT/lib/libblas.a

# Create the top level Makefile with imake
cd $CERN_ROOT/build
$CVSCOSRC/config/imake_boot


%install
export CERN="$RPM_BUILD_ROOT/usr/cernlib"
export CERN_LEVEL=2004
export CERN_ROOT=$CERN/$CERN_LEVEL
export CVSCOSRC=$CERN_ROOT/src
export PATH=$CERN_ROOT/bin:$PATH
cd $CERN_ROOT/build
if [ ! -d /usr/src/linux/include ]; then 
   mkdir -p /usr/src/linux
   ln -s /usr/include /usr/src/linux/include
fi

gmake tree

#
# function to modify Makefiles to replace absolute paths with relative ones
# in soft links (ln -s ... ...) 
#
PREF="../.."; export PREF
ModMake() {
  if [ -f Makefile ]; then
    rm -f sed.tmp
#    cp Makefile Makefile.orig
    cat > sed.tmp <<EOF
/\$(LN) \$@/ s%\$(LN) \$@%\$(LN) \`echo \$@ | sed s?$CERN_ROOT?$PREF?\`%
EOF
    sed -f sed.tmp Makefile  > Makefile.new
    mv Makefile.new Makefile
    rm -f sed.tmp
  fi
}
for i in  mclibs packlib mathlib  graflib phtools  pawlib geant321 patchy
  do
    cd $i
      for k in `ls -1`
        do
          if [ -d $k ]; then
           cd $k
           for j in `ls -1`
             do
              if [ -d $j ]; then
                cd $j
                for l in `ls -1`
                 do
                   if [ -d $l ]; then
                    cd $l
                    PREF="../../../../.."
                    ModMake
                    cd ..
                   fi
                 done
                PREF="../../../.."
                ModMake
                cd ..
              fi
             done
           PREF="../../.."
           ModMake   
           cd ..
          fi
        done
    PREF="../.."
    ModMake
    cd ..
  done
#
# modify patchy Makefile to setup relative soft link 
#
cat > sed.tmp <<EOF
/@ ln -s \$< \$@/ s%\$<%\`echo \$< | sed s?$CERN_ROOT?../..?\`% 
EOF
sed -f sed.tmp $CERN_ROOT/build/patchy/Makefile  > $CERN_ROOT/build/patchy/Makefile.new
mv $CERN_ROOT/build/patchy/Makefile.new $CERN_ROOT/build/patchy/Makefile
rm -f sed.tmp

#
cd scripts
gmake install.bin
cd ..
#
cd packlib
gmake bin/kuipc
gmake install.lib
gmake install.bin

cd ..

#
cd mathlib
gmake install.lib
cd ..
#
cd patchy
gmake install.bin
cd ..
#
cd graflib
gmake install.lib
cd ..
#
cd phtools
gmake install.lib
cd ..
#
cd mclibs
gmake install.lib
cd ..
#
cd pawlib
gmake install.lib
gmake install.bin
cd ..
#
cd geant321
gmake install.lib
cd ..

#
cd $CERN
chown -R root.root $RPM_BUILD_ROOT/usr/cernlib/2004
chown -R root.root $RPM_BUILD_ROOT/usr/cernlib/patchy


%files
/usr/cernlib/2004
/usr/cernlib/patchy


%clean
cd ..
rm -rf cernlib-2004 
rm -rf $RPM_BUILD_ROOT

#  script to run after installing CERN program library

%post
#
#  replace /tmp/cern-2004/usr/cernlib  with $RPM_INSTALL_PREFIX 
# in $RPM_INSTALL_PREFIX/2004/build/*
#
DIR="$RPM_INSTALL_PREFIX/2004/build"
WHAT="\/tmp\/cern-2004\/usr\/cernlib"
WITH="$RPM_INSTALL_PREFIX"
for i in `tar cf - $DIR 2>/dev/null| tar tf -`
  do
     if [ -f /$i ]; then
        if  ( grep "$WHAT" /$i > /dev/null ); then
          sed -e "/$WHAT/ s?$WHAT?$WITH?g"  /$i > /$i.new
          mv /$i.new /$i
        fi
     fi
  done 


#  In order to test some CERNLIB libraries (packlib and geant321)
# one should first, set up variables CERN=/usr/cernlib, CERN_LEVEL=2004,
# CERN_ROOT=$CERN/$CERN_LEVEL
# CVSCOSRC=$CERN/$CERN_LEVEL/src and second, for each library do
# cd $CERN/$CERN_LEVEL/<lib>
# gmake test
# where <lib>  --> packlib and geant321
echo "-----------------------------------------------------------------"
echo "CERN program library (CERNlib) has been  installed in"
echo "$RPM_INSTALL_PREFIX directory."
echo "You should add $RPM_INSTALL_PREFIX/2004/bin to PATH and"
echo "$RPM_INSTALL_PREFIX/2004/lib to  LD_LIBRARY_PATH"
echo "You may install CERNlib in different place, just specify parameter"
echo "--prefix new_dir in command rpm."
echo "------------------------------------------------------------------"

#  script to run after uninstalling CERN program library

%postun
